Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'release/scripts/modules/bpy_types.py')
-rw-r--r--release/scripts/modules/bpy_types.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/release/scripts/modules/bpy_types.py b/release/scripts/modules/bpy_types.py
index 324bb43d890..fd6f8e23727 100644
--- a/release/scripts/modules/bpy_types.py
+++ b/release/scripts/modules/bpy_types.py
@@ -60,7 +60,7 @@ class Library(bpy_types.ID):
# See: readblenentry.c, IDTYPE_FLAGS_ISLINKABLE,
# we could make this an attribute in rna.
attr_links = ("actions", "armatures", "brushes", "cameras",
- "curves", "grease_pencil", "groups", "images",
+ "curves", "grease_pencil", "collections", "images",
"lamps", "lattices", "materials", "metaballs",
"meshes", "node_groups", "objects", "scenes",
"sounds", "speakers", "textures", "texts",
@@ -96,12 +96,12 @@ class Texture(bpy_types.ID):
)
-class Group(bpy_types.ID):
+class Collection(bpy_types.ID):
__slots__ = ()
@property
def users_dupli_group(self):
- """The dupli group this group is used in"""
+ """The collection instance objects this collection is used in"""
import bpy
return tuple(obj for obj in bpy.data.objects
if self == obj.dupli_group)
@@ -118,11 +118,11 @@ class Object(bpy_types.ID):
if child.parent == self)
@property
- def users_group(self):
- """The groups this object is in"""
+ def users_collection(self):
+ """The collections this object is in"""
import bpy
- return tuple(group for group in bpy.data.groups
- if self in group.objects[:])
+ return tuple(collection for collection in bpy.data.collections
+ if self in collection.objects[:])
@property
def users_scene(self):